<?php
if (!defined('ABSPATH')) {
    exit;
}

class WPEMS_Payment_Gateway_Sepordeh extends WPEMS_Abstract_Payment_Gateway
{

    /**
     * id of payment
     * @var null
     */
    public $id = 'sepordeh';
    // title
    public $title = null;
    // email
    protected $sepordeh_merchant = null;
    // url
    protected $sepordeh_url = null;
    // enable
    protected static $enable = false;
    //web gate
    protected $sepordeh_webingate;

    public function __construct()
    {
        $this->title = __('درگاه پرداخت سپرده', 'wp-events-manager');
        $this->icon = plugin_dir_url(__FILE__) . 'sepordeh.png';
        parent::__construct();

        // production environment
        $this->sepordeh_merchant = wpems_get_option('sepordeh_merchant') ? wpems_get_option('sepordeh_merchant') : '';
        $this->sepordeh_url ="https://sepordeh.com/merchant/invoices/pay/automatic:true/id:%s";

    }


    /*
     * Check gateway available
     */
    public function is_available()
    {
        return true;
    }

    /*
     * Check gateway enable
     */
    public function is_enable()
    {
        self::$enable = !empty($this->sepordeh_merchant) && wpems_get_option('sepordeh_enable') === 'yes';
        return apply_filters('tp_event_enable_sepordeh_payment', self::$enable);
    }


    // callback
    public function payment_validation()
    {
        // check validate query
        if (!isset($_GET['event-book']) || !$_GET['event-book']) {
            return;
        }

        $booking_id = absint($_GET['event-book']);

        if (!isset($_GET['tp-event-sepordeh-nonce']) || !wp_verify_nonce($_GET['tp-event-sepordeh-nonce'], 'tp-event-sepordeh-nonce' . $booking_id)) {
            return;
        }

        $book = new WPEMS_Booking($booking_id);
        if (is_null($book)) {
            return;
        }

        // check validate payment
        $Authority = isset($_GET['authority']) ? $_GET['authority'] : '';
        $amount = absint($book->price);
        if ($book->currency == 'IRR') {
            $amount /= 10;
        }

       
$url='https://sepordeh.com/merchant/invoices/verify';
$params= [
		'merchant' 	=> $this->sepordeh_merchant,
		'authority' => $Authority,
	];
	$ch = curl_init();
	curl_setopt($ch, CURLOPT_URL, $url);
	curl_setopt($ch, CURLOPT_POSTFIELDS, $params);
	curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
	curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
	$res = curl_exec($ch);
	curl_close($ch);
$result = json_decode($res);
        if (isset($result->status) && $result->status ==200) {
            if ( $result->status ==200) {
                $status = 'ea-completed';
                $book->update_status($status);
                wpems_add_notice('success', sprintf(__('تراکنش با شماره ' . $Authority . ' پرداخت شد.')));
            } elseif ($result->status == -21) {
                $status = 'ea-cancelled';
                $book->update_status($status);
                wpems_add_notice('error', sprintf(__('تراکنش توسط کاربر لغو شد.')));
            } elseif ($result->status != 200) {
                wpems_add_notice('error', sprintf(__('تراکنش ناموفق! کد خطا: ' . $result->status)));
            }
        }
    }

    /**
     * fields settings
     * @return array
     */
    public function admin_fields()
    {
        $prefix = 'thimpress_events_';
        return apply_filters('tp_event_sepordeh_admin_fields', array(
            array(
                'type' => 'section_start',
                'id' => 'sepordeh_settings',
                'title' => __('تنظیمات درگاه پرداخت سپرده', 'wp-events-manager'),
                'desc' => esc_html__('ساخت درگاه درگاه پرداخت سپرده', 'wp-events-manager')
            ),
            array(
                'type' => 'yes_no',
                'title' => __('فعال کردن', 'wp-events-manager'),
                'id' => $prefix . 'sepordeh_enable',
                'default' => 'no',
                'desc' => apply_filters('tp_event_filter_enable_sepordeh_gateway', '')
            ),
            array(
                'type' => 'text',
                'title' => __('مرچنت کد', 'wp-events-manager'),
                'id' => $prefix . 'sepordeh_merchant',
                'default' => '',
            ),
            array(
                'type' => 'section_end',
                'id' => 'sepordeh_settings'
            )
        ));
    }

    /**
     * get_item_name
     * @return string
     */
    public function get_item_name($booking_id = null)
    {
        if (!$booking_id)
            return;

        // book
        $book = WPEMS_Booking::instance($booking_id);
        $description = sprintf('%s(%s)', $book->post->post_title, wpems_format_price($book->price, $book->currency));

        return $description;
    }

    /**
     * checkout url
     * @return url string
     */
    public function result($booking_id = false)
    {
        if (!$booking_id) {
            wp_send_json(array(
                'status' => false,
                'message' => __('Booking ID is not exists!', 'wp-events-manager')
            ));
            die();
        }
        // book
        $book = wpems_get_booking($booking_id);
        // process amount
        $amount = absint($book->price);
        if ($book->currency != 'IRR' && $book->currency != 'IRT') {
            wp_send_json(array(
                'status' => false,
                'message' => __('برای استفاده از درگاه مبلغ باید به ریال یا تومان باشد.')
            ));
            die();
        }
        if ($book->currency == 'IRR') {
            $amount /= 10;
        }

        // create nonce
        $nonce = wp_create_nonce('tp-event-sepordeh-nonce' . $booking_id);

        $user = get_userdata($book->user_id);
        $email = $user->user_email;
        $callback_url = add_query_arg(array('tp-event-sepordeh-nonce' => $nonce, 'event-book' => $booking_id), wpems_account_url());
        $description = 'شماره رزرو: ' . $booking_id . ' | خریدار: ' . $user->display_name;

	$url='https://sepordeh.com/merchant/invoices/add';
	$params=array(
		'merchant'          => $this->sepordeh_merchant,
		'amount'       => $amount,
		'callback'     => $callback_url,
		'orderId' => $booking_id,
		'description'  => $description,
	);
	$ch = curl_init();
	curl_setopt($ch, CURLOPT_URL, $url);
	curl_setopt($ch, CURLOPT_POSTFIELDS, $params);
	curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
	curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
	$res = curl_exec($ch);
	curl_close($ch);

	$result = json_decode($res);
        return $result;
    }

    public function process($booking_id = false)
    {
        if (!$this->is_available()) {
            return array(
                'status' => false,
                'message' => __('مرچنت کد را بررسی کنید.', 'wp-events-manager')
            );
        }

        $result = $this->result($booking_id);

        if ($result === false) {
            return array(
                'status' => false,
                'message' => __('cURL Error', 'wp-events-manager')
            );
        } else {
            if ( $result->status == 200) {
                return array(
                    'status' => true,
                    'url' => "https://sepordeh.com/merchant/invoices/pay/automatic:true/id:".$result->information->invoice_id,
                );
            } else {
                return array(
                    'status' => false,
                    'message' => ' تراکنش ناموفق، کد خطا : ' . $result->status,
                );
            }
        }

    }

}
